% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/priors-plot.R
\name{geom_prior}
\alias{geom_prior}
\title{Add prior object to a ggplot}
\usage{
geom_prior(
  x,
  xlim = NULL,
  x_seq = NULL,
  x_range_quant = NULL,
  n_points = 1000,
  n_samples = 10000,
  force_samples = FALSE,
  transformation = NULL,
  transformation_arguments = NULL,
  transformation_settings = FALSE,
  show_parameter = if (individual) 1 else NULL,
  individual = FALSE,
  rescale_x = FALSE,
  scale_y2 = 1,
  ...
)
}
\arguments{
\item{x}{a prior}

\item{xlim}{plotting range of the prior}

\item{x_seq}{sequence of x coordinates}

\item{x_range_quant}{quantile used for
automatically obtaining \code{x_range}
if both \code{x_range} and \code{x_seq}
are unspecified. Defaults to \code{0.005}
for all but Cauchy, Student-t, Gamma, and
Inverse-gamme distributions that use
\code{0.010}.}

\item{n_points}{number of equally spaced points
in the \code{x_range} if \code{x_seq} is unspecified}

\item{n_samples}{number of samples from the prior
distribution if the density cannot be obtained
analytically (or if samples are forced with
\code{force_samples = TRUE})}

\item{force_samples}{should prior be sampled instead
of obtaining analytic solution whenever possible}

\item{transformation}{transformation to be applied
to the prior distribution. Either a character
specifying one of the prepared transformations:
\describe{
\item{lin}{linear transformation in form of \code{a + b*x}}
\item{tanh}{also known as Fisher's z transformation}
\item{exp}{exponential transformation}
}, or a list containing the transformation function \code{fun},
inverse transformation function \code{inv}, and the Jacobian of
the transformation \code{jac}. See examples for details.}

\item{transformation_arguments}{a list with named arguments for
the \code{transformation}}

\item{transformation_settings}{boolean indicating whether the
settings the \code{x_seq} or \code{x_range} was specified on
the transformed support}

\item{show_parameter}{which parameter should be returned in case of
multiple parameters per prior. Useful when priors for the omega
parameter are plotted and \code{individual = TRUE}.}

\item{individual}{should individual densities be returned
(e.g., in case of weightfunction)}

\item{rescale_x}{allows to rescale x-axis in case a
weightfunction is plotted.}

\item{scale_y2}{scaling factor for a secondary axis}

\item{...}{additional arguments}
}
\value{
\code{geom_prior_list} returns an object of class 'ggplot'.
}
\description{
Add prior object to a ggplot
}
\seealso{
\code{\link[=plot.prior]{plot.prior()}} \code{\link[=lines.prior]{lines.prior()}}
}
